new

Function new 

pub fn new(config: &Config, upgrade: bool) -> Arc<dyn MetadataStorage>
Creates a new SQLite metadata storage instance.

Opens (or creates) the database specified by config, runs schema migrations when upgrade is true, and returns the storage behind an Arc<dyn MetadataStorage>.